/* EntityDesc.java
 *
 * Copyright (C) 2000  Oskar Liljeblad
 *
 * This file is part of DeDoc.
 *
 * This software is copyrighted work licensed under the terms of the
 * DeDoc License.  Please consult the file "LICENSE" for details.
 */

package org.gjt.osk.dedoc;

/**
 * This is the superclass for classes and class members.
 */
public abstract class EntityDesc {
	/**
	 * Constant indicating public access.
	 * These constants are ordered so that
	 * <tt>PUBLIC</tt> &lt; <tt>PROTECTED</tt> &lt;
	 * <tt>PACKAGE_PRIVATE</tt> &lt; <tt>PRIVATE</tt>.
	 */
	public static final int PUBLIC = 1;
	/** Constant indicating protected access. */
	public static final int PROTECTED = 2;
	/** Constant indicating package-private access. */
	public static final int PACKAGE_PRIVATE = 3;
	/** Constant indicating private access. */
	public static final int PRIVATE = 4;

	/**
	 * Modifiers, such as <tt>abstract</tt>, <tt>private</tt> etc.
	 */
	protected String modifiers;

	/**
	 * Return the modifiers of this member.
	 */
	public String getModifiers() {
		return modifiers;
	}

	/**
	 * Return the access modifier (public, private, ...)
	 * for this member.
	 */
	public int getAccessModifier() {
		if (hasModifier("public")) {
			return PUBLIC;
		}	
		if (hasModifier("protected")) {
			return PROTECTED;
		}	
		if (hasModifier("private")) {
			return PRIVATE;
		}
		return PACKAGE_PRIVATE;
	}

	/**
	 * Return <tt>true</tt> if this entity has the
	 * specified modifier.
	 */
	public boolean hasModifier(String modifier) {
		return (modifiers != null
				&& (modifiers.equals(modifier)
					|| modifiers.startsWith(modifier+" ")
					|| modifiers.endsWith(" "+modifier)
					|| modifiers.indexOf(" "+modifier+" ") != -1));
	}

	/**
	 * Set the modifiers type of this method/constructor.
	 */
	public void setModifiers(String modifiers) {
		this.modifiers = modifiers;
	}
}
