/* FieldDesc.java
 *
 * Copyright (C) 2000  Oskar Liljeblad
 *
 * This file is part of DeDoc.
 *
 * This software is copyrighted work licensed under the terms of the
 * DeDoc License.  Please consult the file "LICENSE" for details.
 */

package org.gjt.osk.dedoc;

import java.io.*;

/**
 * Objects of this class represent fields.
 */
public class FieldDesc extends MemberDesc implements Comparable {
	private String type;

	/**
	 * Create a new field description object.
	 */
	public FieldDesc(ClassDesc classDesc, String name) {
		super(classDesc, name);
	}

	/** Return type of this field. */
	public String getType() {
		return type;
	}

	/**
	 * Return <tt>true</tt> if this field is of scalar type.
	 */
	public boolean isScalarType() {
		return !MemberDesc.getTypeDefaultValue(type).equals("null");
	}

	/** Set the type of this field. */
	public void setType(String type) {
		this.type = type;
	}

	/**
	 * Generate java source for this field.
	 */
	public void generate(JavaSourceWriter out, int bodyLevel) {
		out.print(modifiers+" ");
		out.print(type+" ");
		out.print(name);

		/* Write body. */
		if ((hasModifier("final")
				|| classDesc.hasModifier("interface"))
				&& bodyLevel != 0
				&& bodyLevel != 1) {
			out.print(" = ");
			out.println(MemberDesc.getTypeDefaultValue(type)+";");
		} else {
			out.println(";");
		}
	}
}
