/* MemberDesc.java
 *
 * Copyright (C) 2000  Oskar Liljeblad
 *
 * This file is part of DeDoc.
 *
 * This software is copyrighted work licensed under the terms of the
 * DeDoc License.  Please consult the file "LICENSE" for details.
 */

package org.gjt.osk.dedoc;

/**
 * This is the superclass for class members -
 * fields, methods and constructors.
 */
public abstract class MemberDesc extends EntityDesc {
	/**
	 * Name of this entity.
	 */
	protected String name;

	/**
	 * The class that this member is in.
	 */
	protected ClassDesc classDesc;

	/**
	 * Create a <tt>MemberDesc</tt> object with the specified name.
	 */
	protected MemberDesc(ClassDesc classDesc, String name) {
		this.classDesc = classDesc;
		this.name = name;
	}

	/**
	 * Return the name of this member.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Return a string specifying the default value of
	 * the specified type.
	 */
	public static String getTypeDefaultValue(String type) {
		if (type == null || type.equals("void")) {
			return null;
		} else if (type.equals("boolean")) {
			return "false";
		} else if (type.equals("byte")) {
			return "0";
		} else if (type.equals("char")) {
			return "'\\0'";
		} else if (type.equals("double")) {
			return "0.0";
		} else if (type.equals("float")) {
			return "0F";
		} else if (type.equals("int")) {
			return "0";
		} else if (type.equals("long")) {
			return "0L";
		} else if (type.equals("short")) {
			return "0";
		} else {
			return "null";
		}
	}

	/**
	 * Generate Java source for this member.
	 */
	public abstract void generate(JavaSourceWriter out, int bodyLevel);

	public int compareTo(Object o) {
		MemberDesc e = (MemberDesc) o;

		/* Static+final entities go first. */
		boolean s1 = this.hasModifier("static");
		boolean s2 = e.hasModifier("static");
		boolean f1 = s1 & this.hasModifier("final");
		boolean f2 = s2 & e.hasModifier("final");
		if (f1 ^ f2) {
			return (f1 ? -1 : 1);
		}

		/* Static entities go first. */
		if (s1 ^ s2) {
			return (s1 ? -1 : 1);
		}

		/* Then we sort by access level (public, protected, ..). */
		int accessDiff = e.getAccessModifier() - this.getAccessModifier();
		if (accessDiff != 0) {
			return accessDiff;
		}

		/* Finally by name. */
		return this.name.compareTo(e.name);
	}
}
