/* NodeStateException.java
 * 
 * Copyright (C) 1999-2000  Oskar Liljeblad
 *
 * This file is part of DeDoc.
 *
 * This software is copyrighted work licensed under the terms of the
 * DeDoc License.  Please consult the file "LICENSE" for details.
 */

package org.gjt.osk.util.dom;

import org.w3c.dom.Node;

/**
 * An exception thrown when a method in <tt>NodeState</tt> has
 * failed. This exception represents errors of different kinds -
 * such as "node not found" or "attribute node found".
 */
public class NodeStateException extends RuntimeException {
	private NodeState node;
	private String message;

	/**
	 * Construct a node state exception specifying
	 * node state and a message.
	 */
	public NodeStateException(NodeState node, String message) {
		this.node = node;
		this.message = message;
	}

	/**
	 * Return the message for this exception
	 */
	public String getMessage() {
		String tree = null;
		for (Node n = node.getNode() ; n != null ; n = n.getParentNode()) {
			String name = n.getNodeName();
			tree = (tree == null ? name : name+"->"+tree);
		}
		return message+"\nin "+tree;
	}
}
