package org.gjt.osk.util.options;

/**
 * This is a parser for some standard Java options for gcj-compiled
 * programs. Options such as -D and -classpath (with an alias -cp) are
 * supported. No options are allowed after the first non-option
 * (to simulate the java program).
 */
public class JavaOptionParser extends OptionParser {
	/**
	 * Create a <tt>JavaOptionParser</tt>.
	 */
	public JavaOptionParser() {
		super();
		setPrefix("--", OptionParser.LONG_ABBREV);
		setPrefix("-", OptionParser.SHORT);
		addOption("D", OptionParser.REQUIRED_ARG);
		addOption("cp|classpath", OptionParser.REQUIRED_ARG);
	}

	/**
	 * Process the options and set system properties
	 * accordingly.
	 */
	protected void processOption(String name, Option option) {
		String optName = getFirstName(option.names);

		if (optName.equals("D")) {
			int pos = option.value.indexOf('=');
			System.setProperty(
				(pos == -1 ? option.value : option.value.substring(0, pos)),
				(pos == -1 ? "" : option.value.substring(pos+1)));
		} else if (optName.equals("classpath")) {
			System.setProperty("java.class.path", option.value);
		}
	}

	/**
	 * We disallow more options after the first non-option
	 * argument.
	 */
	protected void processNonOption(String text) {
		noMoreOptions = true;
	}
}
