/* OptionIterator.java
 * 
 * Copyright (C) 1999-2000  Oskar Liljeblad
 *
 * This file is part of Oskar Liljeblad's Utility libraries.
 *
 * This software is copyrighted work licensed under the terms of the
 * GNU GPL License.  Please consult the file "COPYING" for details.
 */

package org.gjt.osk.util.options;

/**
 * Objects of this class are used to process command lines
 * in an interative manner.
 * <p>
 * FIXME: Maybe this class should be made part of the OptionParser?
 * I see no reason to make this a separate class, unless no state
 * data would kept in the OptionParser. This would required adding
 * String getOptionValue(), String[] getNonOptions(), ...
 * <p>
 * FIXME: there is also no way to deal with errors and exceptions
 * when using the OptionIterator.
 */
public class OptionIterator {
	private OptionParser parser;
	String pendingShort;
	Object rememberedPrefix;
	String[] args;
	boolean completed = false;
	int position = 0;
	boolean nextIsOption;
	String nextValue;

	OptionIterator(OptionParser parser, String[] args) {
		this.parser = parser;
		this.args = args;
	}

	/**
	 * Return <tt>true</tt> if there are more options/non-options
	 * to be returned.
	 */
	public boolean hasNext() {
		return !completed;
	}

	/**
	 * Return the next item.
	 */
	public String next()
	throws OptionParserException {
		parser.parseNext(this);
		return nextValue;
	}

	/**
	 * Return <tt>true</tt> if the returned string is an
	 * option. Otherwise it is a non-option string.
	 */
	public boolean isOption() {
		return nextIsOption;
	}
}
